"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
"""
# -*- coding: utf-8 -*-
from libs import crud_base
import base64


class Crud(object):

    def __new__(cls, cluster):

        return super(Crud, cls).__new__(cls)

    def __init__(self, cluster):

        self._seed = cluster.get_seed()

    def create_index(self, cluster, namespace, set_name, index_name, bin_name, bin_type, user=None, password=None):

        node_obj = cluster.get_node(self._seed)
        if node_obj is not None:
            access_ip, access_port = node_obj.get_access_address().rsplit(
                ":", 1)
            sock = node_obj.get_socket_from_queue()
        else:
            access_ip, access_port = self._seed.split(":")
            sock = None

        if cluster.get_status() == "on":
            if set_name is not None:
                response = crud_base.create_index(access_ip, access_port, namespace, index_name, bin_name, bin_type, user=user, password=password, set_name=set_name, sock=sock)
            else:
                response = crud_base.create_index(access_ip, access_port, namespace, index_name, bin_name, bin_type, user=user, password=password, sock=sock)
        else:
            response = dict(status="failure", error="seed node is down")
        return response

    def drop_index(self, cluster, namespace, index_name, user=None, password=None):

        node_obj = cluster.get_node(self._seed)
        if node_obj is not None:
            access_ip, access_port = node_obj.get_access_address().rsplit(
                ":", 1)
            sock = node_obj.get_socket_from_queue()
        else:
            access_ip, access_port = self._seed.split(":")
            sock = None
        if cluster.get_status() == "on":
            response = crud_base.drop_index(access_ip, access_port, namespace, index_name, user=user, password=password, sock=sock)
        else:
            response = dict(status="failure", error="seed node is down")
        return response

    def add_udf(self, cluster, file_name, file_contents, udf_type, user=None, password=None):

        file_contents_base64 = base64.b64encode(str(file_contents))
        content_length = len(file_contents_base64)
        node_obj = cluster.get_node(self._seed)
        if node_obj is not None:
            access_ip, access_port = node_obj.get_access_address().rsplit(
                ":", 1)
            sock = node_obj.get_socket_from_queue()
        else:
            access_ip, access_port = self._seed.split(":")
            sock = None
        if cluster.get_status() == "on":
            response = crud_base.add_udf(access_ip, access_port, file_name, file_contents_base64, content_length, udf_type, user=user, password=password, sock=sock)
        else:
            response = dict(status="failure", error="seed node is down")
        return response

    def drop_udf(self, cluster, file_name, user=None, password=None):

        node_obj = cluster.get_node(self._seed)
        if node_obj is not None:
            access_ip, access_port = node_obj.get_access_address().rsplit(
                ":", 1)
            sock = node_obj.get_socket_from_queue()
        else:
            access_ip, access_port = self._seed.split(":")
            sock = None
        if cluster.get_status() == "on":
            response = crud_base.drop_udf(access_ip, access_port, file_name, user=user, password=password, sock=sock)
        else:
            response = dict(status="failure", error="seed node is down")
        return response
